#
# spec file for package python3-pycrypto
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-pycrypto
Version:        2.6.1
Release:        6.1
Url:            http://www.pycrypto.org/
Summary:        Cryptographic modules for Python
License:        Python-2.0
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/p/pycrypto/pycrypto-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gmp-devel
BuildRequires:  python3-devel

%description
The package contains:

  * Hash functions: MD2, MD4, RIPEMD, SHA256.
  * Block encryption algorithms: AES, ARC2, Blowfish, CAST, DES,
    Triple-DES, IDEA, RC5.
  * Stream encryption algorithms: ARC4, simple XOR.
  * Public-key algorithms: RSA, DSA, ElGamal, qNEW.
  * Protocols: All-or-nothing transforms, chaffing/winnowing.
  * Miscellaneous: RFC1751 module for converting 128-key keys into a
    set of English words, primality testing.
  * Some demo programs (currently all quite old and outdated).

%prep
%setup -q -n pycrypto-%{version}

%build
CFLAGS="%{optflags}" python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
python3 setup.py test

%files
%defattr(-,root,root,-)
%doc ACKS ChangeLog COPYRIGHT README
%{python3_sitearch}/Crypto/
%{python3_sitearch}/pycrypto-%{version}-py%{py3_ver}.egg-info

%changelog
* Sun Dec 21 2014 p.drouand@gmail.com
- Remove useless make requirements
- Remove repreciated python(abi) rependency
- Remove unapplied ignore-fastmath-warning.diff
* Thu Dec 18 2014 arun@gmx.de
- update to version 2.6.1:
  * [CVE-2013-1445] Fix PRNG not correctly reseeded in some situations.
* Wed Apr 24 2013 highwaystar.ru@gmail.com
- update to 2.6
  * [CVE-2012-2417] Fix LP#985164: insecure ElGamal key generation.
    (thanks: Legrandin)
    In the ElGamal schemes (for both encryption and signatures), g is
    supposed to be the generator of the entire Z^*_p group.  However, in
    PyCrypto 2.5 and earlier, g is more simply the generator of a random
    sub-group of Z^*_p.
    The result is that the signature space (when the key is used for
    signing) or the public key space (when the key is used for encryption)
    may be greatly reduced from its expected size of log(p) bits, possibly
    down to 1 bit (the worst case if the order of g is 2).
    While it has not been confirmed, it has also been suggested that an
    attacker might be able to use this fact to determine the private key.
    Anyone using ElGamal keys should generate new keys as soon as practical.
    Any additional information about this bug will be tracked at
    https://bugs.launchpad.net/pycrypto/+bug/985164
  * Huge documentation cleanup (thanks: Legrandin).
  * Added more tests, including test vectors from NIST 800-38A
    (thanks: Legrandin)
  * Remove broken MODE_PGP, which never actually worked properly.
    A new mode, MODE_OPENPGP, has been added for people wishing to write
    OpenPGP implementations.  Note that this does not implement the full
    OpenPGP specification, only the "OpenPGP CFB mode" part of that
    specification.
    https://bugs.launchpad.net/pycrypto/+bug/996814
  * Fix: getPrime with invalid input causes Python to abort with fatal error
    https://bugs.launchpad.net/pycrypto/+bug/988431
  * Fix: Segfaults within error-handling paths
    (thanks: Paul Howarth & Dave Malcolm)
    https://bugs.launchpad.net/pycrypto/+bug/934294
  * Fix: Block ciphers allow empty string as IV
    https://bugs.launchpad.net/pycrypto/+bug/997464
  * Fix DevURandomRNG to work with Python3's new I/O stack.
    (thanks: Sebastian Ramacher)
  * Remove automagic dependencies on libgmp and libmpir, let the caller
    disable them using args.
  * Many other minor bug fixes and improvements (mostly thanks to Legrandin)
* Thu Nov 22 2012 toddrme2178@gmail.com
- Removed openSUSE 11.4 spec file workarounds
* Thu May 24 2012 highwaystar.ru@gmail.com
- python3-pycrypto package added
